@@ -36,7 +36,7 @@ const (
 var PreparationRetryInterval = 3 * time.Second
 
 const (
-	TestAlpineImage       = "alpine:3.7"
+	TestAlpineImage       = "alpine:3.12.0"
 	TestWindowsImage      = "mcr.microsoft.com/windows/servercore:%s"
 	TestAlpineNoRootImage = "registry.gitlab.com/gitlab-org/gitlab-runner/alpine-no-root:latest"
 	TestDockerDindImage   = "docker:18-dind"
