@@ -26,6 +26,7 @@ func (b *AbstractShell) GetFeatures(features *common.FeaturesInfo) {
 	features.Masking = true
 	features.RawVariables = true
 	features.ArtifactsExclude = true
+	features.MultiBuildSteps = true
 }
 
 func (b *AbstractShell) writeCdBuildDir(w ShellWriter, info common.ShellScriptInfo) {
@@ -58,14 +59,14 @@ func (b *AbstractShell) cacheFile(build *common.Build, userKey string) (key, fil
 
 func (b *AbstractShell) guardRunnerCommand(w ShellWriter, runnerCommand string, action string, f func()) {
 	if runnerCommand == "" {
-		w.Warning("%s is not supported by this executor.", action)
+		w.Warningf("%s is not supported by this executor.", action)
 		return
 	}
 
 	w.IfCmd(runnerCommand, "--version")
 	f()
 	w.Else()
-	w.Warning("Missing %s. %s is disabled.", runnerCommand, action)
+	w.Warningf("Missing %s. %s is disabled.", runnerCommand, action)
 	w.EndIf()
 }
 
@@ -93,37 +94,18 @@ func (b *AbstractShell) cacheExtractor(w ShellWriter, info common.ShellScriptInf
 		// Skip extraction if no cache is defined
 		cacheKey, cacheFile := b.cacheFile(info.Build, cacheOptions.Key)
 		if cacheKey == "" {
-			w.Notice("Skipping cache extraction due to empty cache key")
+			w.Noticef("Skipping cache extraction due to empty cache key")
 			continue
 		}
 
 		if ok, err := cacheOptions.CheckPolicy(common.CachePolicyPull); err != nil {
 			return fmt.Errorf("%w for %s", err, cacheKey)
 		} else if !ok {
-			w.Notice("Not downloading cache %s due to policy", cacheKey)
+			w.Noticef("Not downloading cache %s due to policy", cacheKey)
 			continue
 		}
 
-		args := []string{
-			"cache-extractor",
-			"--file", cacheFile,
-			"--timeout", strconv.Itoa(info.Build.GetCacheRequestTimeout()),
-		}
-
-		// Generate cache download address
-		if url := cache.GetCacheDownloadURL(info.Build, cacheKey); url != nil {
-			args = append(args, "--url", url.String())
-		}
-
-		// Execute cache-extractor command. Failure is not fatal.
-		b.guardRunnerCommand(w, info.RunnerCommand, "Extracting cache", func() {
-			w.Notice("Checking cache for %s...", cacheKey)
-			w.IfCmdWithOutput(info.RunnerCommand, args...)
-			w.Notice("Successfully extracted cache")
-			w.Else()
-			w.Warning("Failed to extract cache")
-			w.EndIf()
-		})
+		b.addExtractCacheCommand(w, info, cacheFile, cacheKey)
 	}
 
 	if skipRestoreCache {
@@ -133,6 +115,34 @@ func (b *AbstractShell) cacheExtractor(w ShellWriter, info common.ShellScriptInf
 	return nil
 }
 
+func (b *AbstractShell) addExtractCacheCommand(
+	w ShellWriter,
+	info common.ShellScriptInfo,
+	cacheFile string,
+	cacheKey string,
+) {
+	args := []string{
+		"cache-extractor",
+		"--file", cacheFile,
+		"--timeout", strconv.Itoa(info.Build.GetCacheRequestTimeout()),
+	}
+
+	// Generate cache download address
+	if url := cache.GetCacheDownloadURL(info.Build, cacheKey); url != nil {
+		args = append(args, "--url", url.String())
+	}
+
+	// Execute cache-extractor command. Failure is not fatal.
+	b.guardRunnerCommand(w, info.RunnerCommand, "Extracting cache", func() {
+		w.Noticef("Checking cache for %s...", cacheKey)
+		w.IfCmdWithOutput(info.RunnerCommand, args...)
+		w.Noticef("Successfully extracted cache")
+		w.Else()
+		w.Warningf("Failed to extract cache")
+		w.EndIf()
+	})
+}
+
 func (b *AbstractShell) downloadArtifacts(w ShellWriter, job common.Dependency, info common.ShellScriptInfo) {
 	args := []string{
 		"artifacts-downloader",
@@ -144,7 +154,7 @@ func (b *AbstractShell) downloadArtifacts(w ShellWriter, job common.Dependency,
 		strconv.Itoa(job.ID),
 	}
 
-	w.Notice("Downloading artifacts for %s (%d)...", job.Name, job.ID)
+	w.Noticef("Downloading artifacts for %s (%d)...", job.Name, job.ID)
 	w.Command(info.RunnerCommand, args...)
 }
 
@@ -203,13 +213,14 @@ func (b *AbstractShell) writeExports(w ShellWriter, info common.ShellScriptInfo)
 }
 
 func (b *AbstractShell) writeGitSSLConfig(w ShellWriter, build *common.Build, where []string) {
-	repoURL, err := url.Parse(build.Runner.URL)
+	repoURL, err := url.Parse(build.GetRemoteURL())
 	if err != nil {
-		w.Warning("git SSL config: Can't parse repository URL. %s", err)
+		w.Warningf("git SSL config: Can't parse repository URL. %s", err)
 		return
 	}
 
 	repoURL.Path = ""
+	repoURL.User = nil
 	host := repoURL.String()
 	variables := build.GetCITLSVariables()
 	args := append([]string{"config"}, where...)
@@ -270,7 +281,7 @@ func (b *AbstractShell) writeCloneFetchCmds(w ShellWriter, info common.ShellScri
 			w.EndIf()
 		}
 	} else {
-		w.Notice("Skipping Git checkout")
+		w.Noticef("Skipping Git checkout")
 	}
 
 	return nil
@@ -278,16 +289,15 @@ func (b *AbstractShell) writeCloneFetchCmds(w ShellWriter, info common.ShellScri
 
 func (b *AbstractShell) handleGetSourcesStrategy(w ShellWriter, build *common.Build) error {
 	projectDir := build.FullProjectDir()
-	gitDir := path.Join(build.FullProjectDir(), ".git")
 
 	switch build.GetGitStrategy() {
 	case common.GitFetch:
-		b.writeRefspecFetchCmd(w, build, projectDir, gitDir)
+		b.writeRefspecFetchCmd(w, build, projectDir)
 	case common.GitClone:
 		w.RmDir(projectDir)
-		b.writeRefspecFetchCmd(w, build, projectDir, gitDir)
+		b.writeRefspecFetchCmd(w, build, projectDir)
 	case common.GitNone:
-		w.Notice("Skipping Git repository setup")
+		w.Noticef("Skipping Git repository setup")
 		w.MkDir(projectDir)
 	default:
 		return errors.New("unknown GIT_STRATEGY")
@@ -296,18 +306,18 @@ func (b *AbstractShell) handleGetSourcesStrategy(w ShellWriter, build *common.Bu
 	return nil
 }
 
-func (b *AbstractShell) writeRefspecFetchCmd(w ShellWriter, build *common.Build, projectDir string, gitDir string) {
+func (b *AbstractShell) writeRefspecFetchCmd(w ShellWriter, build *common.Build, projectDir string) {
 	depth := build.GitInfo.Depth
 
 	if depth > 0 {
-		w.Notice("Fetching changes with git depth set to %d...", depth)
+		w.Noticef("Fetching changes with git depth set to %d...", depth)
 	} else {
-		w.Notice("Fetching changes...")
+		w.Noticef("Fetching changes...")
 	}
 
 	// initializing
 	templateDir := w.MkTmpDir("git-template")
-	templateFile := path.Join(templateDir, "config")
+	templateFile := w.Join(templateDir, "config")
 
 	w.Command("git", "config", "-f", templateFile, "fetch.recurseSubmodules", "false")
 	if build.IsSharedEnv() {
@@ -316,11 +326,11 @@ func (b *AbstractShell) writeRefspecFetchCmd(w ShellWriter, build *common.Build,
 
 	w.Command("git", "init", projectDir, "--template", templateDir)
 	w.Cd(projectDir)
-	b.writeGitCleanup(w, build)
+	b.writeGitCleanup(w)
 
 	// Add `git remote` or update existing
 	w.IfCmd("git", "remote", "add", "origin", build.GetRemoteURL())
-	w.Notice("Created fresh repository.")
+	w.Noticef("Created fresh repository.")
 	w.Else()
 	w.Command("git", "remote", "set-url", "origin", build.GetRemoteURL())
 	w.EndIf()
@@ -336,7 +346,7 @@ func (b *AbstractShell) writeRefspecFetchCmd(w ShellWriter, build *common.Build,
 	w.Command("git", fetchArgs...)
 }
 
-func (b *AbstractShell) writeGitCleanup(w ShellWriter, build *common.Build) {
+func (b *AbstractShell) writeGitCleanup(w ShellWriter) {
 	// Remove .git/{index,shallow,HEAD}.lock files from .git, which can fail the fetch command
 	// The file can be left if previous build was terminated during git operation
 	w.RmFile(".git/index.lock")
@@ -347,7 +357,7 @@ func (b *AbstractShell) writeGitCleanup(w ShellWriter, build *common.Build) {
 }
 
 func (b *AbstractShell) writeCheckoutCmd(w ShellWriter, build *common.Build) {
-	w.Notice("Checking out %s as %s...", build.GitInfo.Sha[0:8], build.GitInfo.Ref)
+	w.Noticef("Checking out %s as %s...", build.GitInfo.Sha[0:8], build.GitInfo.Ref)
 	w.Command("git", "checkout", "-f", "-q", build.GitInfo.Sha)
 
 	cleanFlags := build.GetGitCleanFlags()
@@ -368,7 +378,7 @@ func (b *AbstractShell) writeSubmoduleUpdateCmds(w ShellWriter, info common.Shel
 		b.writeSubmoduleUpdateCmd(w, build, true)
 
 	case common.SubmoduleNone:
-		w.Notice("Skipping Git submodules setup")
+		w.Noticef("Skipping Git submodules setup")
 
 	default:
 		return errors.New("unknown GIT_SUBMODULE_STRATEGY")
@@ -379,9 +389,9 @@ func (b *AbstractShell) writeSubmoduleUpdateCmds(w ShellWriter, info common.Shel
 
 func (b *AbstractShell) writeSubmoduleUpdateCmd(w ShellWriter, build *common.Build, recursive bool) {
 	if recursive {
-		w.Notice("Updating/initializing submodules recursively...")
+		w.Noticef("Updating/initializing submodules recursively...")
 	} else {
-		w.Notice("Updating/initializing submodules...")
+		w.Noticef("Updating/initializing submodules...")
 	}
 
 	// Sync .git/config to .gitmodules in case URL changes (e.g. new build token)
@@ -435,9 +445,9 @@ func (b *AbstractShell) writeCommands(w ShellWriter, commands ...string) {
 			lines := strings.SplitN(command, "\n", 2)
 			if len(lines) > 1 {
 				// TODO: this should be collapsable once we introduce that in GitLab
-				w.Notice("$ %s # collapsed multi-line command", lines[0])
+				w.Noticef("$ %s # collapsed multi-line command", lines[0])
 			} else {
-				w.Notice("$ %s", lines[0])
+				w.Noticef("$ %s", lines[0])
 			}
 		} else {
 			w.EmptyLine()
@@ -447,7 +457,11 @@ func (b *AbstractShell) writeCommands(w ShellWriter, commands ...string) {
 	}
 }
 
-func (b *AbstractShell) writeUserScript(w ShellWriter, info common.ShellScriptInfo, buildStage common.BuildStage) error {
+func (b *AbstractShell) writeUserScript(
+	w ShellWriter,
+	info common.ShellScriptInfo,
+	buildStage common.BuildStage,
+) error {
 	var scriptStep *common.Step
 	for _, step := range info.Build.Steps {
 		if common.StepToBuildStage(step) == buildStage {
@@ -500,39 +514,18 @@ func (b *AbstractShell) cacheArchiver(w ShellWriter, info common.ShellScriptInfo
 		// Skip archiving if no cache is defined
 		cacheKey, cacheFile := b.cacheFile(info.Build, cacheOptions.Key)
 		if cacheKey == "" {
-			w.Notice("Skipping cache archiving due to empty cache key")
+			w.Noticef("Skipping cache archiving due to empty cache key")
 			continue
 		}
 
 		if ok, err := cacheOptions.CheckPolicy(common.CachePolicyPush); err != nil {
 			return fmt.Errorf("%w for %s", err, cacheKey)
 		} else if !ok {
-			w.Notice("Not uploading cache %s due to policy", cacheKey)
+			w.Noticef("Not uploading cache %s due to policy", cacheKey)
 			continue
 		}
 
-		args := []string{
-			"cache-archiver",
-			"--file", cacheFile,
-			"--timeout", strconv.Itoa(info.Build.GetCacheRequestTimeout()),
-		}
-
-		args = append(args, archiverArgs...)
-
-		// Generate cache upload address
-		if url := cache.GetCacheUploadURL(info.Build, cacheKey); url != nil {
-			args = append(args, "--url", url.String())
-		}
-
-		// Execute cache-archiver command. Failure is not fatal.
-		b.guardRunnerCommand(w, info.RunnerCommand, "Creating cache", func() {
-			w.Notice("Creating cache %s...", cacheKey)
-			w.IfCmdWithOutput(info.RunnerCommand, args...)
-			w.Notice("Created cache")
-			w.Else()
-			w.Warning("Failed to create cache")
-			w.EndIf()
-		})
+		b.addCacheUploadCommand(w, info, cacheFile, archiverArgs, cacheKey)
 	}
 
 	if skipArchiveCache {
@@ -542,6 +535,37 @@ func (b *AbstractShell) cacheArchiver(w ShellWriter, info common.ShellScriptInfo
 	return nil
 }
 
+func (b *AbstractShell) addCacheUploadCommand(
+	w ShellWriter,
+	info common.ShellScriptInfo,
+	cacheFile string,
+	archiverArgs []string,
+	cacheKey string,
+) {
+	args := []string{
+		"cache-archiver",
+		"--file", cacheFile,
+		"--timeout", strconv.Itoa(info.Build.GetCacheRequestTimeout()),
+	}
+
+	args = append(args, archiverArgs...)
+
+	// Generate cache upload address
+	if url := cache.GetCacheUploadURL(info.Build, cacheKey); url != nil {
+		args = append(args, "--url", url.String())
+	}
+
+	// Execute cache-archiver command. Failure is not fatal.
+	b.guardRunnerCommand(w, info.RunnerCommand, "Creating cache", func() {
+		w.Noticef("Creating cache %s...", cacheKey)
+		w.IfCmdWithOutput(info.RunnerCommand, args...)
+		w.Noticef("Created cache")
+		w.Else()
+		w.Warningf("Failed to create cache")
+		w.EndIf()
+	})
+}
+
 func (b *AbstractShell) writeUploadArtifact(w ShellWriter, info common.ShellScriptInfo, artifact common.Artifact) bool {
 	args := []string{
 		"artifacts-uploader",
@@ -592,7 +616,7 @@ func (b *AbstractShell) writeUploadArtifact(w ShellWriter, info common.ShellScri
 	}
 
 	b.guardRunnerCommand(w, info.RunnerCommand, "Uploading artifacts", func() {
-		w.Notice("Uploading artifacts...")
+		w.Noticef("Uploading artifacts...")
 		w.Command(info.RunnerCommand, args...)
 	})
 
@@ -610,14 +634,11 @@ func (b *AbstractShell) writeUploadArtifacts(w ShellWriter, info common.ShellScr
 	skipUploadArtifacts := true
 
 	for _, artifact := range info.Build.Artifacts {
-		if onSuccess {
-			if !artifact.When.OnSuccess() {
-				continue
-			}
-		} else {
-			if !artifact.When.OnFailure() {
-				continue
-			}
+		if onSuccess && !artifact.When.OnSuccess() {
+			continue
+		}
+		if !onSuccess && !artifact.When.OnFailure() {
+			continue
 		}
 
 		if b.writeUploadArtifact(w, info, artifact) {
@@ -648,7 +669,7 @@ func (b *AbstractShell) writeAfterScript(w ShellWriter, info common.ShellScriptI
 	b.writeExports(w, info)
 	b.writeCdBuildDir(w, info)
 
-	w.Notice("Running after script...")
+	w.Noticef("Running after script...")
 	b.writeCommands(w, afterScriptStep.Script...)
 	return nil
 }
